aboutsummaryrefslogtreecommitdiff
path: root/util/sconfig/sconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'util/sconfig/sconfig.h')
-rw-r--r--util/sconfig/sconfig.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/util/sconfig/sconfig.h b/util/sconfig/sconfig.h
index 78c44d64da..389d697a33 100644
--- a/util/sconfig/sconfig.h
+++ b/util/sconfig/sconfig.h
@@ -102,8 +102,9 @@ struct device {
/* Monotonically increasing ID for the device. */
int id;
/* Indicates whether this device is enabled. */
int enabled;
+ int hidden;
/* Subsystem IDs for the device. */
int subsystem_vendor;
@@ -147,7 +148,7 @@ extern struct bus *root_parent;
struct device *new_device(struct bus *parent,
struct chip_instance *chip_instance,
const int bustype, const char *devnum,
- int enabled);
+ int status);
void add_resource(struct bus *bus, int type, int index, int base);
@@ -102,8 +102,9 @@ struct device {
/* Monotonically increasing ID for the device. */
int id;
- /* Indicates whether this device is enabled. */
+ /* Indicates device status (enabled / hidden or not). */
int enabled;